Clazz.declarePackage("JSV.api");
Clazz.declareInterface(JSV.api, "JSVAppletInterface");
;//5.0.1-v7 Thu Feb 05 13:38:23 CST 2026
